@@ -3,7 +3,7 @@ import pathlib, argparse, sys, os, logging
 from abritamr.AmrSetup import SetupAMR, SetupMDU
 from abritamr.RunFinder import RunFinder
 from abritamr.Collate import Collate, MduCollate
-from abritamr.version import __version__
+from abritamr.version import __version__, db
 
 """
 abritamr is designed to implement AMRFinder and parse the results compatible for MDU use. It may also be used for other purposes where the format of output is compatible
@@ -30,7 +30,7 @@ def mdu(args):
 
 def main():
     parser = argparse.ArgumentParser(
-        description="AMR gene detection pipeline", formatter_class=argparse.ArgumentDefaultsHelpFormatter
+        description=f"****AMR gene detection pipeline - version {__version__}****", formatter_class=argparse.ArgumentDefaultsHelpFormatter
     )
     parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + __version__)
     
@@ -64,7 +64,7 @@ def main():
     parser_sub_run.add_argument(
         "--amrfinder_db", 
         "-d", 
-        default=f"{pathlib.Path(__file__).parent.parent /'abritamr' /'db' / 'amrfinderplus' / 'data' / '2021-09-30.1/'}", 
+        default=f"{pathlib.Path(__file__).parent.parent /'abritamr' /'db' / 'amrfinderplus' / 'data' / f'{db}/'}", 
         # default="/home/khhor/conda/envs/abritamr/share/amrfinderplus/data/2021-09-30.1/",
         help="Path to amrfinder DB to use"
     )
@@ -73,7 +73,7 @@ def main():
         "-sp",
         default="",
         help="Set if you would like to use point mutations, please provide a valid species.",
-        choices= ['Neisseria','Clostridioides_difficile', 'Acinetobacter_baumannii', "Campylobacter", "Enterococcus_faecalis", "Enterococcus_faecium", "Escherichia", "Klebsiella", "Salmonella", "Staphylococcus_aureus", "Staphylococcus_pseudintermedius", "Streptococcus_agalactiae", "Streptococcus_pneumoniae", "Streptococcus_pyogenes"]
+        choices= ["Burkholderia_cepacia","Acinetobacter_baumannii","Streptococcus_pyogenes","Streptococcus_agalactiae","Streptococcus_pneumoniae","Enterococcus_faecium","Pseudomonas_aeruginosa","Staphylococcus_pseudintermedius","Clostridioides_difficile","Klebsiella","Neisseria","Campylobacter","Salmonella","Escherichia","Staphylococcus_aureus","Burkholderia_pseudomallei","Enterococcus_faecalis"]
     )
     parser_mdu = subparsers.add_parser('report', help='Generate report for use at MDU', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     
@@ -105,7 +105,12 @@ def main():
         "--sop",
         default=f"general",
         choices = ['general', 'plus'],
-        help="The MDU pipeline for reporting results."
+        help="The pipeline for reporting results."
+    )
+    parser_mdu.add_argument(
+        "--sop_name",
+        default=f"",
+        help="The name of the process - will be reflected in the names od the output files."
     )
 
     
